Module gateway

Module gateway 

Structs

GatewayState
Gateway state structure

Enums

Platform
Platform enum for gateway
ServiceStatus
Service status enum

Functions

gateway_pid_path
Gateway PID file path
gateway_state_path
Gateway state file path
get_running_pid
Get the PID of running gateway instance, if any
get_service_status
Get the status of the Hermes Windows service
install_service
Install the gateway as a Windows service using sc.exe
is_gateway_running
Check if gateway is currently running
is_service_installed
Check if the gateway is installed as a Windows service
read_gateway_state
Read gateway state from file
remove_pid_file
Remove PID file
start_service
Start the gateway Windows service
stop_service
Stop the gateway Windows service
uninstall_service
Uninstall the gateway Windows service
write_gateway_state
Write gateway state to file
write_pid_file
Write PID file for gateway process with metadata