Structs
- Gateway
State - Gateway state structure
Enums
- Platform
- Platform enum for gateway
- Service
Status - Service status enum
Functions
- gateway_
pid_ path - Gateway PID file path
- gateway_
state_ path - Gateway state file path
- get_
running_ pid - Get the PID of running gateway instance, if any
- get_
service_ status - Get the status of the Hermes Windows service
- install_
service - Install the gateway as a Windows service using sc.exe
- is_
gateway_ running - Check if gateway is currently running
- is_
service_ installed - Check if the gateway is installed as a Windows service
- read_
gateway_ state - Read gateway state from file
- remove_
pid_ file - Remove PID file
- start_
service - Start the gateway Windows service
- stop_
service - Stop the gateway Windows service
- uninstall_
service - Uninstall the gateway Windows service
- write_
gateway_ state - Write gateway state to file
- write_
pid_ file - Write PID file for gateway process with metadata